@@ -71,6 +71,8 @@ static void       window_activate_new_tab         (GtkAction       *action,
 						   DhWindow        *window);
 static void       window_activate_close           (GtkAction       *action,
 						   DhWindow        *window);
+static void       window_activate_quit            (GtkAction       *action,
+						   DhWindow        *window);
 static void       window_activate_copy            (GtkAction       *action,
 						   DhWindow        *window);
 static void       window_activate_preferences     (GtkAction       *action,
@@ -148,6 +150,8 @@ static const GtkActionEntry actions[] = {
 	  G_CALLBACK (window_activate_new_tab) },
 	{ "Close", GTK_STOCK_CLOSE, NULL, NULL, NULL,
 	  G_CALLBACK (window_activate_close) },
+	{ "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL,
+	  G_CALLBACK (window_activate_quit) },
 
 	/* Edit menu */
 	{ "Copy", GTK_STOCK_COPY, NULL, "<control>C", NULL,
@@ -290,9 +294,12 @@ window_init (DhWindow *window)
 static void
 window_finalize (GObject *object)
 {
-	if (G_OBJECT_CLASS (parent_class)->finalize) {
-		G_OBJECT_CLASS (parent_class)->finalize (object);
-	}
+	DhWindow *window = DH_WINDOW (object);
+	DhBase *base = window->priv->base;
+
+	G_OBJECT_CLASS (parent_class)->finalize (object);
+
+	g_object_unref (base);
 }
 
 /* The ugliest hack. When switching tabs, the selection and cursor is changed
@@ -506,6 +513,12 @@ window_activate_close (GtkAction *action, DhWindow *window)
 	}
 }
 
+static void
+window_activate_quit (GtkAction *action, DhWindow *window)
+{
+	gtk_main_quit ();
+}
+
 static void
 window_activate_copy (GtkAction *action, DhWindow *window)
 {
@@ -1087,7 +1100,6 @@ dh_window_new (DhBase *base)
 {
         DhWindow     *window;
         DhWindowPriv *priv;
-	GdkPixbuf    *icon;
 
         window = g_object_new (DH_TYPE_WINDOW, NULL);
         priv = window->priv;
@@ -1102,12 +1114,7 @@ dh_window_new (DhBase *base)
 	window_populate (window);
 	window_restore_state (window);
 
-	icon = gdk_pixbuf_new_from_file (DATA_DIR "/pixmaps/devhelp.png",
-					 NULL);
-	if (icon) {
-		gtk_window_set_icon (GTK_WINDOW (window), icon);
-		g_object_unref (icon);
-	}
+	gtk_window_set_icon_name (GTK_WINDOW (window), "devhelp");
 
 	return GTK_WIDGET (window);
 }
